@@ -1,11 +1,14 @@
 """Módulo de iteração de listas
 """
-def print_lol(the_list):
+def print_lol(the_list, level):
     """Função que recebe uma lista e itera. A lista pode conter vários níveis de profundiade
     """
         
     for each_item in the_list:
         if(isinstance(each_item, list)):
-            print_lol(each_item)
+            print_lol(each_item, level+1)
         else:
+            for tab_stop in range(level):
+                print("\t", end='')
+
             print(each_item)
